@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Create network transition chord progressions
 
-our $VERSION = '0.0202';
+our $VERSION = '0.0203';
 
 use Data::Dumper::Compact qw(ddc);
 use Graph::Directed;
@@ -158,11 +158,11 @@ sub generate {
 
     my @scale = get_scale_notes($self->scale_note, $self->scale_name);
 
-    my $chords = $self->chords;
+    my @chords = @{ $self->chords };
 
     if ($self->substitute) {
         my $i = 0;
-        for my $chord (@$chords) {
+        for my $chord (@chords) {
             my $substitute = $self->sub_cond->() ? $self->substitution($chord) : $chord;
             if ($substitute eq $chord) {
                 if ($self->sub_cond->()) {
@@ -174,7 +174,7 @@ sub generate {
         }
     }
 
-    my @phrase = map { $self->_tt_sub(\@scale, $chords, $_) } @progression;
+    my @phrase = map { $self->_tt_sub(\@scale, \@chords, $_) } @progression;
     print "Phrase: @phrase\n" if $self->verbose;
 
     # Add octaves to the chord notes
@@ -214,26 +214,14 @@ sub _full_keys {
 sub _tt_sub {
     my ($self, $scale, $chords, $n) = @_;
 
-    my %tritone = (
-        'C'  => 'F#',
-        'C#' => 'G',
-        'D'  => 'G#',
-        'D#' => 'A',
-        'E'  => 'A#',
-        'F'  => 'B',
-        'F#' => 'C',
-        'G'  => 'C#',
-        'G#' => 'D',
-        'A'  => 'D#',
-        'A#' => 'E',
-        'B'  => 'F',
-    );
+    my @notes = get_scale_notes('C', 'chromatic');
+    my %tritone = map { $notes[$_] => $notes[($_ + 6) % @notes] } 0 .. $#notes;
 
     my $note;
     if ($n =~ /t/) {
         $n =~ s/t//;
         $note = $tritone{ $scale->[$n - 1] };
-        print "TT: $scale->[$n - 1] => $note\n" if $self->verbose;
+        print "Tritone: $scale->[$n - 1] => $note\n" if $self->verbose;
     }
     else {
         $note = $scale->[$n - 1];
@@ -273,7 +261,7 @@ sub substitution {
         $substitute = $roll == 0 ? 'm9' : $roll == 1 ? 'm11' : 'm13';
     }
 
-    print "Sub: $chord => $substitute\n" if $self->verbose && $substitute ne $chord;
+    print "Substitute: $chord => $substitute\n" if $self->verbose && $substitute ne $chord;
 
     return $substitute;
 }
@@ -292,7 +280,7 @@ Music::Chord::Progression - Create network transition chord progressions
 
 =head1 VERSION
 
-version 0.0202
+version 0.0203
 
 =head1 SYNOPSIS
 
